@@ -1201,7 +1201,8 @@ print_screen (WnckScreen *screen)
                                 wnck_workspace_get_number (space),
                                 wnck_workspace_get_name (space));
   else
-    free_buf = g_strdup (_("none"));
+    /* Translators: "none" here means "no workspace" */
+    free_buf = g_strdup (Q_("workspace|none"));
   g_print (_("Active Workspace: %s\n"), free_buf);
   g_free (free_buf);
 
@@ -1222,7 +1223,8 @@ print_screen (WnckScreen *screen)
       g_free (name);
     }
   else
-    free_buf = g_strdup (_("none"));
+    /* Translators: "none" here means "no window" */
+    free_buf = g_strdup (Q_("window|none"));
   g_print (_("Active Window: %s\n"), free_buf);
   g_free (free_buf);
 
@@ -1278,7 +1280,8 @@ print_workspace (WnckWorkspace *space)
                                 wnck_workspace_get_number (neighbor),
                                 wnck_workspace_get_name (neighbor));
   else
-    free_buf = g_strdup (_("none"));
+    /* Translators: "none" here means "no workspace" */
+    free_buf = g_strdup (Q_("workspace|none"));
   g_print (_("Left Neighbor: %s\n"), free_buf);
   g_free (free_buf);
 
@@ -1289,7 +1292,8 @@ print_workspace (WnckWorkspace *space)
                                 wnck_workspace_get_number (neighbor),
                                 wnck_workspace_get_name (neighbor));
   else
-    free_buf = g_strdup (_("none"));
+    /* Translators: "none" here means "no workspace" */
+    free_buf = g_strdup (Q_("workspace|none"));
   g_print (_("Right Neighbor: %s\n"), free_buf);
   g_free (free_buf);
 
@@ -1300,7 +1304,8 @@ print_workspace (WnckWorkspace *space)
                                 wnck_workspace_get_number (neighbor),
                                 wnck_workspace_get_name (neighbor));
   else
-    free_buf = g_strdup (_("none"));
+    /* Translators: "none" here means "no workspace" */
+    free_buf = g_strdup (Q_("workspace|none"));
   g_print (_("Top Neighbor: %s\n"), free_buf);
   g_free (free_buf);
 
@@ -1311,7 +1316,8 @@ print_workspace (WnckWorkspace *space)
                                 wnck_workspace_get_number (neighbor),
                                 wnck_workspace_get_name (neighbor));
   else
-    free_buf = g_strdup (_("none"));
+    /* Translators: "none" here means "no workspace" */
+    free_buf = g_strdup (Q_("workspace|none"));
   g_print (_("Bottom Neighbor: %s\n"), free_buf);
   g_free (free_buf);
 }
@@ -1373,7 +1379,8 @@ print_application (WnckApplication *app)
   if (wnck_application_get_startup_id (app) != NULL)
     buf = wnck_application_get_startup_id (app);
   else
-    buf = _("none");
+    /* Translators: "none" here means "no startup ID" */
+    buf = Q_("startupID|none");
   g_print (_("Startup ID: %s\n"), buf);
 
   g_print (_("Number of Windows: %d\n"), g_list_length (windows));
@@ -1424,7 +1431,8 @@ print_window (WnckWindow *window)
   else if (wnck_window_is_pinned (window))
     free_buf = g_strdup (_("all workspaces"));
   else
-    free_buf = g_strdup (_("none"));
+    /* Translators: "none" here means "no workspace" */
+    free_buf = g_strdup (Q_("workspace|none"));
   g_print (_("On Workspace: %s\n"), free_buf);
   g_free (free_buf);
 
@@ -1790,7 +1798,9 @@ main (int argc, char **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  ctxt = g_option_context_new ("");
+  ctxt = g_option_context_new (NULL);
+  g_option_context_set_translation_domain (ctxt, GETTEXT_PACKAGE);
+
   g_option_context_set_summary (ctxt,
                                 N_("Print or modify the properties of a "
                                    "screen/workspace/window, or interact with "
@@ -1806,6 +1816,7 @@ main (int argc, char **argv)
                               N_("Show options to list windows or workspaces"),
                               NULL, NULL);
   g_option_group_add_entries (group, list_entries);
+  g_option_group_set_translation_domain (group, GETTEXT_PACKAGE);
   g_option_context_add_group (ctxt, group);
 
   group = g_option_group_new ("window",
@@ -1813,6 +1824,7 @@ main (int argc, char **argv)
                               N_("Show options to modify properties of a window"),
                               NULL, NULL);
   g_option_group_add_entries (group, window_entries);
+  g_option_group_set_translation_domain (group, GETTEXT_PACKAGE);
   g_option_context_add_group (ctxt, group);
 
   group = g_option_group_new ("workspace",
@@ -1820,6 +1832,7 @@ main (int argc, char **argv)
                               N_("Show options to modify properties of a workspace"),
                               NULL, NULL);
   g_option_group_add_entries (group, space_entries);
+  g_option_group_set_translation_domain (group, GETTEXT_PACKAGE);
   g_option_context_add_group (ctxt, group);
 
   group = g_option_group_new ("screen",
@@ -1827,6 +1840,7 @@ main (int argc, char **argv)
                               N_("Show options to modify properties of a screen"),
                               NULL, NULL);
   g_option_group_add_entries (group, screen_entries);
+  g_option_group_set_translation_domain (group, GETTEXT_PACKAGE);
   g_option_context_add_group (ctxt, group);
 
   g_option_context_add_group (ctxt, gtk_get_option_group (TRUE));
